pub struct LoginData {
pub login_name: String,
pub password: String,
}Expand description
The submitted login data from a client.
Note: For multi factor authentication you need to take some custom action (for now) or rely on a trusted proxy that does the job of logging the user in.
Fields
login_name: Stringpassword: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for LoginData
impl<'de> Deserialize<'de> for LoginData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more