pub struct DisplayField {
pub name: String,
pub label: String,
pub template: String,
pub default: Option<String>,
pub required: bool,
pub additional_options: HashMap<String, Value>,
}Expand description
A field that is <input type=text disabled>. Used to display some static information that is not
supposed to be set or edited by the user (like an entity’s id)
Fields
name: Stringlabel: Stringtemplate: Stringdefault: Option<String>required: booladditional_options: HashMap<String, Value>Implementations
Sourceimpl DisplayField
impl DisplayField