pub struct HtmlInputField {
pub name: String,
pub label: String,
pub template: String,
pub default: Option<String>,
pub required: bool,
pub additional_options: HashMap<String, Value>,
}Expand description
A field that is configurable in the <input type=$TYPE>. It comes with a label and except for this
is just a plain old HTML input element. This can be used for things that do not (yet) have a respective
*Field type.
Fields
name: Stringlabel: Stringtemplate: Stringdefault: Option<String>required: booladditional_options: HashMap<String, Value>Implementations