pub struct AdminCreateFormPageLoader<S, F> { /* private fields */ }Trait Implementations
Sourceimpl<S: Clone, F> Clone for AdminCreateFormPageLoader<S, F>
impl<S: Clone, F> Clone for AdminCreateFormPageLoader<S, F>
Sourceimpl<S, F> FromState<S> for AdminCreateFormPageLoader<S, F>
impl<S, F> FromState<S> for AdminCreateFormPageLoader<S, F>
fn from_state(state: &S) -> Self
Sourceimpl<S, F> TemplateDataLoader<S> for AdminCreateFormPageLoader<S, F>where
S: ProvideState<AdminPageLoader> + Send + Sync + Clone + 'static,
F: Send + Sync + 'static + AdminCreateForm<S>,
impl<S, F> TemplateDataLoader<S> for AdminCreateFormPageLoader<S, F>where
S: ProvideState<AdminPageLoader> + Send + Sync + Clone + 'static,
F: Send + Sync + 'static + AdminCreateForm<S>,
type Args = (Method, <AdminPageLoader as TemplateDataLoader<S>>::Args)
type Data = AdminPageData<AdminFormCreatePageData>
async fn load_data(&self, __arg1: Self::Args) -> Result<Self::Data>
Sourceasync fn render_error(&self, error: Error) -> impl IntoResponse
async fn render_error(&self, error: Error) -> impl IntoResponse
Map an emitted error to a response, this can be used to render another error template instead of the plain error text
fn data_load_call(
&self,
template: &'static str,
parts: &mut Parts,
state: &S,
) -> impl Future<Output = Response<Body>> + Sendwhere
<Self::Args as FromRequestParts<S>>::Rejection: Send,
Self::Args: Send,
S: Send + Sync + ProvideState<Templating> + 'static,
Self: Sync,
fn get_additional_response_parts( &self, _args: Self::Args, ) -> impl IntoResponseParts