pub struct DbAuthProvider { /* private fields */ }Trait Implementations
Sourceimpl<S: Send + Sync + 'static> AdminAuthProvider<S> for DbAuthProvider
impl<S: Send + Sync + 'static> AdminAuthProvider<S> for DbAuthProvider
type AuthParams = Extension<Session>
Sourceasync fn authenticate(
&self,
params: Self::AuthParams,
) -> Result<Option<AuthenticatedUser>>
async fn authenticate( &self, params: Self::AuthParams, ) -> Result<Option<AuthenticatedUser>>
Authenticate the user by whatever is required from the request to identify the user. If a AuthenticatedUser is returned no other
Auth provider will have the chance of authenticating against the request.
Authorize the request to the authenticated user. As soon as a provider returns a “true” no other provider will be asked about it anymore.
Sourcefn provider_name(&self) -> &str
fn provider_name(&self) -> &str
Internal function for error reporting + tracing
Sourceimpl Clone for DbAuthProvider
impl Clone for DbAuthProvider
Sourcefn clone(&self) -> DbAuthProvider
fn clone(&self) -> DbAuthProvider
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<State> FromState<State> for DbAuthProviderwhere
State: State + ProvideState<UserRepository> + ProvideState<GroupRepository> + ProvideState<PermissionRepository>,
impl<State> FromState<State> for DbAuthProviderwhere
State: State + ProvideState<UserRepository> + ProvideState<GroupRepository> + ProvideState<PermissionRepository>,
fn from_state(state: &State) -> Self