AdminState

Struct AdminState 

pub struct AdminState<S> {
    pub title: String,
    pub navigation_groups: HashMap<String, AdminNavigationGroup>,
    pub sidebar_widgets: Vec<AdminSidebarWidget>,
    pub dashboard_widgets: Vec<AdminDashboardWidget>,
    pub entities: Vec<Arc<dyn TypeErasedEntityHandler<S> + Send + Sync>>,
    pub auth_providers: AuthProviders<S>,
    pub login_url: String,
    pub super_admin_group: Option<String>,
    pub login_providers: LoginProviders,
}

Fields

title: Stringnavigation_groups: HashMap<String, AdminNavigationGroup>sidebar_widgets: Vec<AdminSidebarWidget>dashboard_widgets: Vec<AdminDashboardWidget>entities: Vec<Arc<dyn TypeErasedEntityHandler<S> + Send + Sync>>auth_providers: AuthProviders<S>login_url: Stringsuper_admin_group: Option<String>login_providers: LoginProviders

Implementations

Source

impl<S> AdminState<S>
where S: State + 'static,

pub fn add_navigation(&mut self, group: impl Into<AdminNavigationGroup>)

Adds a navigation section for your bundle

Examples found in repository?
examples/full-admin.rs (lines 74-78)
67    fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68        let admin: &mut AdminState<_> = state.provide_mut();
69
70        admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71        admin.add_auth_provider(TestAuthProvider);
72        admin.add_login_provider(TestLoginProvider);
73
74        admin.add_navigation(
75            AdminNavigationGroup::new("Example").add(
76                NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77            ),
78        );
79
80        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88        admin.register_entity_handler(EntityHandler::<
89            S,
90            TestEntityCreateForm,
91            TestEntityUpdateForm,
92            TestEntityListing,
93        >::new("Example"));
94
95        Ok(())
96    }
pub fn get_navigation(&self) -> Vec<AdminNavigationGroup>

Gets an ordered version of the navigation

pub fn add_sidebar_widget(&mut self, widget: impl Into<AdminSidebarWidget>)

Adds a sidebar widget, check AdminSidebarWidget for details

Examples found in repository?
examples/full-admin.rs (line 80)
67    fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68        let admin: &mut AdminState<_> = state.provide_mut();
69
70        admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71        admin.add_auth_provider(TestAuthProvider);
72        admin.add_login_provider(TestLoginProvider);
73
74        admin.add_navigation(
75            AdminNavigationGroup::new("Example").add(
76                NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77            ),
78        );
79
80        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88        admin.register_entity_handler(EntityHandler::<
89            S,
90            TestEntityCreateForm,
91            TestEntityUpdateForm,
92            TestEntityListing,
93        >::new("Example"));
94
95        Ok(())
96    }
pub fn add_dashboard_widget(&mut self, widget: impl Into<AdminDashboardWidget>)

Adds a dashboard widget, check AdminDashboardWidget for details

Examples found in repository?
examples/full-admin.rs (line 83)
67    fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68        let admin: &mut AdminState<_> = state.provide_mut();
69
70        admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71        admin.add_auth_provider(TestAuthProvider);
72        admin.add_login_provider(TestLoginProvider);
73
74        admin.add_navigation(
75            AdminNavigationGroup::new("Example").add(
76                NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77            ),
78        );
79
80        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88        admin.register_entity_handler(EntityHandler::<
89            S,
90            TestEntityCreateForm,
91            TestEntityUpdateForm,
92            TestEntityListing,
93        >::new("Example"));
94
95        Ok(())
96    }
pub fn register_entity_handler<C, U, L>( &mut self, handler: EntityHandler<S, C, U, L>, )

Registers your custom entity to be managable in the admin-ui. Check the EntityHandler for more details.

Examples found in repository?
examples/full-admin.rs (lines 88-93)
67    fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68        let admin: &mut AdminState<_> = state.provide_mut();
69
70        admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71        admin.add_auth_provider(TestAuthProvider);
72        admin.add_login_provider(TestLoginProvider);
73
74        admin.add_navigation(
75            AdminNavigationGroup::new("Example").add(
76                NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77            ),
78        );
79
80        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88        admin.register_entity_handler(EntityHandler::<
89            S,
90            TestEntityCreateForm,
91            TestEntityUpdateForm,
92            TestEntityListing,
93        >::new("Example"));
94
95        Ok(())
96    }
pub fn register_routes(&self, router: Router<S>) -> Router<S>

Registers the route for the [AdminBundle]

pub fn add_auth_provider<P: AdminAuthProvider<S> + InnerAuthProvider<S> + 'static>( &mut self, provider: P, )

Adds a custom auth provider. Check the AdminAuthProvider for more details.

Examples found in repository?
examples/full-admin.rs (line 71)
67    fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68        let admin: &mut AdminState<_> = state.provide_mut();
69
70        admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71        admin.add_auth_provider(TestAuthProvider);
72        admin.add_login_provider(TestLoginProvider);
73
74        admin.add_navigation(
75            AdminNavigationGroup::new("Example").add(
76                NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77            ),
78        );
79
80        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88        admin.register_entity_handler(EntityHandler::<
89            S,
90            TestEntityCreateForm,
91            TestEntityUpdateForm,
92            TestEntityListing,
93        >::new("Example"));
94
95        Ok(())
96    }
pub fn add_login_provider<P: AdminLoginProvider + InnerLoginProvider + Send + Sync + 'static>( &mut self, provider: P, )

Adds a custom login provider. Check the AdminLoginProvider for details.

Examples found in repository?
examples/full-admin.rs (line 72)
67    fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68        let admin: &mut AdminState<_> = state.provide_mut();
69
70        admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71        admin.add_auth_provider(TestAuthProvider);
72        admin.add_login_provider(TestLoginProvider);
73
74        admin.add_navigation(
75            AdminNavigationGroup::new("Example").add(
76                NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77            ),
78        );
79
80        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81        admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86        admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88        admin.register_entity_handler(EntityHandler::<
89            S,
90            TestEntityCreateForm,
91            TestEntityUpdateForm,
92            TestEntityListing,
93        >::new("Example"));
94
95        Ok(())
96    }