pub struct AdminBundle {}Trait Implementations
Sourceimpl<S> Pouch<S> for AdminBundlewhere
S: ProvideState<Templating> + ProvideState<Database> + ProvideStateRef<AdminState<S>> + State + 'static,
This is provides the minimum to get a Bundle started.
impl<S> Pouch<S> for AdminBundlewhere
S: ProvideState<Templating> + ProvideState<Database> + ProvideStateRef<AdminState<S>> + State + 'static,
This is provides the minimum to get a Bundle started.
See the quokka::bundle::Pouch for available setup functions.
Sourcefn from_config(_: &Config) -> Result<Self>where
Self: Sized,
fn from_config(_: &Config) -> Result<Self>where
Self: Sized,
Find your config module from here
fn configure_commands(&self, commands: &mut Commands<S>) -> Result<()>
Sourcefn configure_state(&mut self, state: &mut S) -> Result<()>
fn configure_state(&mut self, state: &mut S) -> Result<()>
This function can be used to interact with the sub-states of other libraries. Read more
fn configure_styles(&mut self, styles: &mut Styling) -> Result<()>
fn configure_scripts(&mut self, scripts: &mut Scripting) -> Result<()>
fn configure_templates(&mut self, templates: &mut Templating) -> Result<()>
fn configure_resources(&mut self, resources: &mut Resources) -> Result<()>
Sourcefn get_router(&mut self, state: &S) -> Router<S>
fn get_router(&mut self, state: &S) -> Router<S>
Sets up a router for the local bundle. Read more
Sourcefn get_migrations(&self) -> Option<Migrator>
fn get_migrations(&self) -> Option<Migrator>
Gets the migrations for this bundle