pub struct AdminSidebarWidget {
pub template: String,
pub data: HashMap<String, Value>,
}Expand description
Provides a way to add widgets to the sidebar by loading a template and populating it with the provided data.
For more-interactive widgets see the AdminSidebarWidget::htmx constructor which allows you to include a widget from any HTML-serving URL using htmx.
Fields
template: Stringdata: HashMap<String, Value>Implementations
Sourceimpl AdminSidebarWidget
impl AdminSidebarWidget
Sourcepub fn htmx(url: impl ToString) -> Self
pub fn htmx(url: impl ToString) -> Self
Examples found in repository?
examples/full-admin.rs (line 80)
67 fn configure_state(&mut self, state: &mut S) -> quokka::Result<()> {
68 let admin: &mut AdminState<_> = state.provide_mut();
69
70 admin.super_admin_group = EXAMPLE_SUPER_USER_GROUP.to_string().into(); // This can be and usually should be set via the config
71 admin.add_auth_provider(TestAuthProvider);
72 admin.add_login_provider(TestLoginProvider);
73
74 admin.add_navigation(
75 AdminNavigationGroup::new("Example").add(
76 NavigationItem::new("example_page", "Example Page").link("/admin/example/page"),
77 ),
78 );
79
80 admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/test_widget"));
81 admin.add_sidebar_widget(AdminSidebarWidget::htmx("/example/admin/time_widget")); // .hx_trigger("load, every 1s") // This widget should be refreshed, but as it spams the console I leave this comment here so you know that it is possible
82
83 admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
84 admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
85 admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
86 admin.add_dashboard_widget(AdminDashboardWidget::htmx("/example/admin/test_widget"));
87
88 admin.register_entity_handler(EntityHandler::<
89 S,
90 TestEntityCreateForm,
91 TestEntityUpdateForm,
92 TestEntityListing,
93 >::new("Example"));
94
95 Ok(())
96 }pub fn new(template: impl ToString) -> Self
pub fn data<S: Serialize>(self, name: impl ToString, value: S) -> Self
pub fn hx_trigger(self, trigger: impl ToString) -> Self